#logout-form {
    display: inline;
    float: right;
    margin-right: 20px;
}

#logout-form button {
  background: none;
  border: none;
  cursor: pointer;
  padding: 0;
  text-decoration: underline;
}
